@@ -3,10 +3,14 @@
 Visit https://github.com/kerkelae/dkmri for more info.
 """
 
+__version__ = "0.1.0"
+
 from .dkmri import *
 from .dkmri import (
     _adc,
     _akc,
+    _45_dirs,
+    _10_dirs,
     _vec2vec_rotmat,
     _mtk,
     _ols_fit,
