@@ -17,7 +17,7 @@ from sklearn.neural_network import MLPRegressor
 jax.config.update("jax_enable_x64", True)
 jax.config.update("jax_platform_name", "cpu")
 
-# Hard-coded lower and upper limit for kurtosis
+# Hard-coded lower and upper limit for kurtosis in prediction step
 MIN_K = -3 / 7
 MAX_K = 10
 
@@ -1251,8 +1251,8 @@ if __name__ == "__main__":
 
     parser = argparse.ArgumentParser(
         description=(
-            """Estimate diffusion kurtosis imaging parameters and compute parameter maps.
-            The command for using dkmri.py is "dkmri.py data bvals bvecs
+            """Estimate diffusion kurtosis imaging parameters and compute parameter
+            maps. The command for using dkmri.py is "dkmri.py data bvals bvecs
             optional-arguments", where data, bvals, and bvecs are the paths of the files
             containing the diffusion-weighted data, b-values, and b-vectors, and
             optional-arguments is where to define things such as which parameter maps to
@@ -1271,9 +1271,19 @@ if __name__ == "__main__":
     parser.add_argument(
         "-mask",
         help=(
-            "path of a NIfTI file with a mask definining where to estimate parameters"
+            "path of a NIfTI file with a binary mask definining where to estimate"
+            + " parameters"
         ),
     )
+    parser.add_argument(
+        "-alpha",
+        help="value of the constant controlling regularization magnitude"
+        + " (default values is 0.1 * MSE_NLLS / MSE_MK)",
+    )
+    parser.add_argument(
+        "-params",
+        help="path of a NIfTI file in which to save the estimated parameters",
+    )
     parser.add_argument(
         "-md", help="path of a NIfTI file in which to save the mean diffusivity map"
     )
@@ -1316,8 +1326,18 @@ if __name__ == "__main__":
         help="path of a NIfTI file in which to save the codes returned by the optimizer",
     )
     parser.add_argument(
-        "-params",
-        help="path of a NIfTI file in which to save the estimated parameters",
+        "-params_nlls",
+        help=(
+            "path of a NIfTI file in which to save the parameter estimates computed"
+            + " with standard NLLS"
+        ),
+    )
+    parser.add_argument(
+        "-akc_mask",
+        help=(
+            "path of a NIfTI file in which to save the mask defining the voxels where"
+            + " the NLLS fit was considered successful"
+        ),
     )
     args = parser.parse_args()
 
@@ -1332,8 +1352,12 @@ if __name__ == "__main__":
         mask = nib.load(args.mask).get_fdata().astype(bool)
     else:
         mask = None
+    if args.alpha:
+        alpha = float(args.alpha)
+    else:
+        alpha = None
 
-    fit_result = fit(data, bvals, bvecs, mask)
+    fit_result = fit(data, bvals, bvecs, mask, alpha)
 
     if args.md:
         nib.save(
@@ -1375,3 +1399,13 @@ if __name__ == "__main__":
         nib.save(nib.Nifti1Image(fit_result.status, affine), args.status)
     if args.params:
         nib.save(nib.Nifti1Image(fit_result.params, affine), args.params)
+    if args.params_nlls:
+        nib.save(nib.Nifti1Image(fit_result.params_nlls, affine), args.params_nlls)
+    if args.mk_nlls:
+        nib.save(
+            nib.Nifti1Image(params_to_mk(fit_result.params_nlls), affine), args.mk_nlls
+        )
+    if args.akc_mask:
+        nib.save(
+            nib.Nifti1Image(fit_result.akc_mask.astype(float), affine), args.akc_mask
+        )
